@@ -16,13 +16,13 @@ class GoeChargerStatusMapper:
 
     def mapApiStatusResponse(self, status):
         car_status = GoeCharger.GO_CAR_STATUS.get(status.get('car')) or 'unknown'
-        charger_max_current = int(status.get('amp',0))
-        charger_absolute_max_current = int(status.get('ama',0))
+        charger_max_current = int(status.get('amp', 0))
+        charger_absolute_max_current = int(status.get('ama', 0))
         charger_err = GoeCharger.GO_ERR.get(status.get('err')) or 'UNKNOWN'
         charger_access = GoeCharger.GO_ACCESS.get(status.get('ast')) or 'unknown'
         allow_charging = GoeCharger.GO_ALLOW_CHARGING.get(status.get('alw')) or 'unknown'
         stop_mode = GoeCharger.GO_STOP_MODE.get(status.get('stp')) or 'unknown'
-        cable_max_current = int(status.get('cbl',0))
+        cable_max_current = int(status.get('cbl', 0))
 
         try:
             phase = int(status.get('pha'))
@@ -33,30 +33,31 @@ class GoeChargerStatusMapper:
             post_contactor_l1 = self.__phaseDetection(phase, 0x04)
             post_contactor_l2 = self.__phaseDetection(phase, 0x02)
             post_contactor_l3 = self.__phaseDetection(phase, 0x01)
-        except:
-            pre_contactor_l1 = pre_contactor_l2 =  pre_contactor_l3 = post_contactor_l1 = post_contactor_l2 = post_contactor_l3 = 'unknown'
+        except Exception:
+            pre_contactor_l1 = pre_contactor_l2 = pre_contactor_l3 = 'unknown'
+            post_contactor_l1 = post_contactor_l2 = post_contactor_l3 = 'unknown'
 
-        charger_temp = int(status.get('tmp',0))
-        current_session_charged_energy = round(int(status.get('dws',0)) / 360000.0,5)
-        charge_limit = int(status.get('dwo',0)) / 10.0
+        charger_temp = int(status.get('tmp', 0))
+        current_session_charged_energy = round(int(status.get('dws', 0)) / 360000.0, 5)
+        charge_limit = int(status.get('dwo', 0)) / 10.0
         adapter = GoeCharger.GO_ADAPTER.get(status.get('adi')) or 'unknown'
-        unlocked_by_card = int(status.get('uby',0))
-        energy_total = int(status.get('eto',0)) / 10.0
-        wifi = 'connected' if status.get('wst') == '3' else 'unknown' if status.get('wst') == None else 'not connected'
+        unlocked_by_card = int(status.get('uby', 0))
+        energy_total = int(status.get('eto', 0)) / 10.0
+        wifi = 'connected' if status.get('wst') == '3' else 'unknown' if status.get('wst') is None else 'not connected'
         firmware = status.get('fwv', 'unknown')
         serial_number = status.get('sse', 'unknown')
         wifi_ssid = status.get('wss', 'unknown')
         wifi_enabled = 'on' if status.get('wen') == '1' else 'off' if status.get('wen') == '0' else 'unknown'
-        timezone_offset = int(status.get('tof',0)) - 100
-        timezone_dst_offset = int(status.get('tds',0)) 
+        timezone_offset = int(status.get('tof', 0)) - 100
+        timezone_dst_offset = int(status.get('tds', 0))
 
         def valueOrNull(array, index):
-            try: 
+            try:
                 return array[index]
             except IndexError:
                 return 0
 
-        return ( {
+        return ({
             'car_status': car_status,
             'charger_max_current': charger_max_current,
             'charger_absolute_max_current': charger_absolute_max_current,
@@ -79,22 +80,22 @@ class GoeChargerStatusMapper:
             'energy_total': energy_total,
             'wifi': wifi,
 
-            'u_l1': int(valueOrNull(status.get('nrg',[]),GoeCharger.U_L1)),
-            'u_l2': int(valueOrNull(status.get('nrg',[]),GoeCharger.U_L2)),
-            'u_l3': int(valueOrNull(status.get('nrg',[]),GoeCharger.U_L3)),
-            'u_n': int(valueOrNull(status.get('nrg',[]),GoeCharger.U_N)),
-            'i_l1': int(valueOrNull(status.get('nrg',[]),GoeCharger.I_L1)) / 10.0,
-            'i_l2': int(valueOrNull(status.get('nrg',[]),GoeCharger.I_L2)) / 10.0,
-            'i_l3': int(valueOrNull(status.get('nrg',[]),GoeCharger.I_L3)) / 10.0,
-            'p_l1': int(valueOrNull(status.get('nrg',[]),GoeCharger.P_L1)) / 10.0,
-            'p_l2': int(valueOrNull(status.get('nrg',[]),GoeCharger.P_L2)) / 10.0,
-            'p_l3': int(valueOrNull(status.get('nrg',[]),GoeCharger.P_L3)) / 10.0,
-            'p_n': int(valueOrNull(status.get('nrg',[]),GoeCharger.P_N)) / 10.0,
-            'p_all': int(valueOrNull(status.get('nrg',[]),GoeCharger.P_ALL)) / 100.0,
-            'lf_l1': int(valueOrNull(status.get('nrg',[]),GoeCharger.LF_L1)),
-            'lf_l2': int(valueOrNull(status.get('nrg',[]),GoeCharger.LF_L2)),
-            'lf_l3': int(valueOrNull(status.get('nrg',[]),GoeCharger.LF_L3)),
-            'lf_n': int(valueOrNull(status.get('nrg',[]),GoeCharger.LF_N)),
+            'u_l1': int(valueOrNull(status.get('nrg', []), GoeCharger.U_L1)),
+            'u_l2': int(valueOrNull(status.get('nrg', []), GoeCharger.U_L2)),
+            'u_l3': int(valueOrNull(status.get('nrg', []), GoeCharger.U_L3)),
+            'u_n': int(valueOrNull(status.get('nrg', []), GoeCharger.U_N)),
+            'i_l1': int(valueOrNull(status.get('nrg', []), GoeCharger.I_L1)) / 10.0,
+            'i_l2': int(valueOrNull(status.get('nrg', []), GoeCharger.I_L2)) / 10.0,
+            'i_l3': int(valueOrNull(status.get('nrg', []), GoeCharger.I_L3)) / 10.0,
+            'p_l1': int(valueOrNull(status.get('nrg', []), GoeCharger.P_L1)) / 10.0,
+            'p_l2': int(valueOrNull(status.get('nrg', []), GoeCharger.P_L2)) / 10.0,
+            'p_l3': int(valueOrNull(status.get('nrg', []), GoeCharger.P_L3)) / 10.0,
+            'p_n': int(valueOrNull(status.get('nrg', []), GoeCharger.P_N)) / 10.0,
+            'p_all': int(valueOrNull(status.get('nrg', []), GoeCharger.P_ALL)) / 100.0,
+            'lf_l1': int(valueOrNull(status.get('nrg', []), GoeCharger.LF_L1)),
+            'lf_l2': int(valueOrNull(status.get('nrg', []), GoeCharger.LF_L2)),
+            'lf_l3': int(valueOrNull(status.get('nrg', []), GoeCharger.LF_L3)),
+            'lf_n': int(valueOrNull(status.get('nrg', []), GoeCharger.LF_N)),
 
             'firmware': firmware,
             'serial_number': serial_number,
@@ -105,15 +106,15 @@ class GoeChargerStatusMapper:
 
         })
 
+
 class GoeCharger:
     host = ''
 
     def __init__(self, host):
-        if (host == None or host == ''):
+        if (host is None or host == ''):
             raise ValueError("host must be specified")
         self.host = host
 
-
     GO_CAR_STATUS = {
         '1': 'Charger ready, no vehicle',
         '2': 'charging',
@@ -139,18 +140,18 @@ class GoeCharger:
     U_L1 = 0
     U_L2 = 1
     U_L3 = 2
-    U_N  = 3
+    U_N = 3
     I_L1 = 4
     I_L2 = 5
     I_L3 = 6
     P_L1 = 7
     P_L2 = 8
     P_L3 = 9
-    P_N  = 10
-    P_ALL= 11
-    LF_L1= 12
-    LF_L2= 13
-    LF_L3= 14
+    P_N = 10
+    P_ALL = 11
+    LF_L1 = 12
+    LF_L2 = 13
+    LF_L3 = 14
     LF_N = 15
 
     GO_ERR = {
@@ -163,7 +164,7 @@ class GoeCharger:
 
     GO_ACCESS = {
         '0': 'free',
-        '1': 'rfid/app' ,
+        '1': 'rfid/app',
         '2': 'cost based / automatic'
     }
 
@@ -178,24 +179,32 @@ class GoeCharger:
 
     def __queryStatusApi(self):
         try:
-            statusRequest = requests.get("http://%s/status" % self.host, timeout=5) # TODO: Configurable Timeout
+            statusRequest = requests.get("http://%s/status" % self.host, timeout=5)  # TODO: Configurable Timeout
             status = statusRequest.json()
             return status
-        except requests.exceptions.ConnectTimeout:
+        except (requests.exceptions.ConnectTimeout, requests.exceptions.ConnectionError):
             return {}
-    
+
     def __setParameter(self, parameter, value):
         setRequest = requests.get("http://%s/mqtt?payload=%s=%s" % (self.host, parameter, value))
         return GoeChargerStatusMapper().mapApiStatusResponse(setRequest.json())
 
     def setAccessType(self, accessType):
-        if accessType == GoeCharger.AccessType.FREE or accessType == GoeCharger.AccessType.RFID_APP or accessType == GoeCharger.AccessType.AUTO:
+        if (
+            accessType == GoeCharger.AccessType.FREE or
+            accessType == GoeCharger.AccessType.RFID_APP or
+            accessType == GoeCharger.AccessType.AUTO
+        ):
             return self.__setParameter('ast', str(accessType.value))
 
         raise ValueError('Invalid AccessType: %d provided' % accessType)
 
     def setLockType(self, lockType):
-        if lockType == GoeCharger.LockType.UNLOCKCARFIRST or lockType == GoeCharger.LockType.AUTOMATIC or lockType == GoeCharger.LockType.LOCKED:
+        if (
+            lockType == GoeCharger.LockType.UNLOCKCARFIRST or
+            lockType == GoeCharger.LockType.AUTOMATIC or
+            lockType == GoeCharger.LockType.LOCKED
+        ):
             return self.__setParameter('ust', str(lockType.value))
 
         raise ValueError('Invalid LockType: %d provided' % lockType)
@@ -268,4 +277,4 @@ class GoeCharger:
     def requestStatus(self):
         status = self.__queryStatusApi()
         response = GoeChargerStatusMapper().mapApiStatusResponse(status)
-        return response
\ No newline at end of file
+        return response
